@@ -33,6 +33,6 @@
 #include <gdl/gdl-dock-notebook.h>
 #include <gdl/gdl-dock-tablabel.h>
 #include <gdl/gdl-dock-bar.h>
-#include <gdl/gdl-combo-button.h>
+#include <gdl/gdl-switcher.h>
 
 #endif
